==> openflowplugin-extension-nicira-0.5.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/reg/move/grouping/nx/reg/move/Src.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.nx.reg.move;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.RangeGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.SrcChoiceGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * Writes value to bits start through end, inclusive, in field src.
 *
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container src {
 *     choice src-choice {
 *         case src-nx-arp-sha-case {
 *             leaf nx-arp-sha {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-arp-tha-case {
 *             leaf nx-arp-tha {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-encap-eth-dst-case {
 *             leaf nx-encap-eth-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-encap-eth-src-case {
 *             leaf nx-encap-eth-src {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-ipv6-dst-case {
 *             leaf nx-ipv6-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-ipv6-src-case {
 *             leaf nx-ipv6-src {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsh-mdtype-case {
 *             leaf nx-nsh-mdtype {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsh-np-case {
 *             leaf nx-nsh-np {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-1-case {
 *             leaf nx-nshc-1-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-2-case {
 *             leaf nx-nshc-2-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-3-case {
 *             leaf nx-nshc-3-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-4-case {
 *             leaf nx-nshc-4-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsi-case {
 *             leaf nx-nsi-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsp-case {
 *             leaf nx-nsp-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-of-in-port-case {
 *             leaf of-in-port {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-of-metadata-case {
 *             leaf of-metadata {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-of-mpls-label-case {
 *             leaf of-mpls-label {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-reg-case {
 *             leaf nx-reg {
 *                 type identityref;
 *             }
 *         }
 *         case src-nx-tun-gpe-np-case {
 *             leaf nx-tun-gpe-np {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-tun-id-case {
 *             leaf nx-tun-id {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-tun-ipv4-dst-case {
 *             leaf nx-tun-ipv4-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-tun-ipv4-src-case {
 *             leaf nx-tun-ipv4-src {
 *                 type empty;
 *             }
 *         }
 *         case src-of-arp-op-case {
 *             leaf of-arp-op {
 *                 type empty;
 *             }
 *         }
 *         case src-of-arp-spa-case {
 *             leaf of-arp-spa {
 *                 type empty;
 *             }
 *         }
 *         case src-of-arp-tpa-case {
 *             leaf of-arp-tpa {
 *                 type empty;
 *             }
 *         }
 *         case src-of-eth-dst-case {
 *             leaf of-eth-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-of-eth-src-case {
 *             leaf of-eth-src {
 *                 type empty;
 *             }
 *         }
 *         case src-of-eth-type-case {
 *             leaf of-eth-type {
 *                 type empty;
 *             }
 *         }
 *         case src-of-ip-dst-case {
 *             leaf of-ip-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-of-ip-src-case {
 *             leaf of-ip-src {
 *                 type empty;
 *             }
 *         }
 *     }
 *     leaf start {
 *         type uint16;
 *     }
 *     leaf end {
 *         type uint16;
 *     }
 *     uses src-choice-grouping;
 *     uses range-grouping;
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-reg-move-grouping/nx-reg-move/src</i>
 *
 * <p>To create instances of this class use {@link org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.nx.reg.move.SrcBuilder}.
 * @see org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.nx.reg.move.SrcBuilder
 *
 */
public interface Src
    extends
    ChildOf<NxRegMove>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.nx.reg.move.Src>,
    SrcChoiceGrouping,
    RangeGrouping
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "src").intern();


}

==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/reg/move/grouping/nx/reg/move/Src.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.nx.reg.move;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.RangeGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.SrcChoiceGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * Writes value to bits start through end, inclusive, in field src.
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container src {
 *     choice src-choice {
 *         case src-nx-arp-sha-case {
 *             leaf nx-arp-sha {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-arp-tha-case {
 *             leaf nx-arp-tha {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-encap-eth-dst-case {
 *             leaf nx-encap-eth-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-encap-eth-src-case {
 *             leaf nx-encap-eth-src {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-ipv6-dst-case {
 *             leaf nx-ipv6-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-ipv6-src-case {
 *             leaf nx-ipv6-src {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsh-mdtype-case {
 *             leaf nx-nsh-mdtype {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsh-np-case {
 *             leaf nx-nsh-np {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-1-case {
 *             leaf nx-nshc-1-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-2-case {
 *             leaf nx-nshc-2-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-3-case {
 *             leaf nx-nshc-3-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nshc-4-case {
 *             leaf nx-nshc-4-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsi-case {
 *             leaf nx-nsi-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-nsp-case {
 *             leaf nx-nsp-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-of-in-port-case {
 *             leaf of-in-port {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-of-metadata-case {
 *             leaf of-metadata {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-of-mpls-label-case {
 *             leaf of-mpls-label {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-reg-case {
 *             leaf nx-reg {
 *                 type identityref;
 *             }
 *         }
 *         case src-nx-tun-gpe-np-case {
 *             leaf nx-tun-gpe-np {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-tun-id-case {
 *             leaf nx-tun-id {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-tun-ipv4-dst-case {
 *             leaf nx-tun-ipv4-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-nx-tun-ipv4-src-case {
 *             leaf nx-tun-ipv4-src {
 *                 type empty;
 *             }
 *         }
 *         case src-of-arp-op-case {
 *             leaf of-arp-op {
 *                 type empty;
 *             }
 *         }
 *         case src-of-arp-spa-case {
 *             leaf of-arp-spa {
 *                 type empty;
 *             }
 *         }
 *         case src-of-arp-tpa-case {
 *             leaf of-arp-tpa {
 *                 type empty;
 *             }
 *         }
 *         case src-of-eth-dst-case {
 *             leaf of-eth-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-of-eth-src-case {
 *             leaf of-eth-src {
 *                 type empty;
 *             }
 *         }
 *         case src-of-eth-type-case {
 *             leaf of-eth-type {
 *                 type empty;
 *             }
 *         }
 *         case src-of-ip-dst-case {
 *             leaf of-ip-dst {
 *                 type empty;
 *             }
 *         }
 *         case src-of-ip-src-case {
 *             leaf of-ip-src {
 *                 type empty;
 *             }
 *         }
 *     }
 *     leaf start {
 *         type uint16;
 *     }
 *     leaf end {
 *         type uint16;
 *     }
 *     uses src-choice-grouping;
 *     uses range-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-reg-move-grouping/nx-reg-move/src</i>
 *
 * <p>To create instances of this class use {@link SrcBuilder}.
 * @see SrcBuilder
 *
 */
public interface Src
    extends
    ChildOf<NxRegMove>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.nx.reg.move.Src>,
    SrcChoiceGrouping,
    RangeGrouping
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "src").intern();


}
